@@ -10,7 +10,6 @@ from sqlalchemy.orm import DeclarativeBase, Mapped, mapped_column, relationship
 from sqlalchemy_utils import create_database, database_exists, drop_database  # type: ignore
 
 from dev_utils.sqlalchemy.types.datetime import UTCDateTime
-from dev_utils.sqlalchemy.types.pydantic import PydanticType
 
 if TYPE_CHECKING:
     from collections.abc import Sequence
@@ -240,4 +239,3 @@ class TableWithUTCDT(Base):  # noqa: D101
 
     id: Mapped[int] = mapped_column(primary_key=True)  # noqa
     dt_field: Mapped[datetime.datetime] = mapped_column(UTCDateTime)
-    pydantic_field: Mapped[PydanticTestSchema] = mapped_column(PydanticType(PydanticTestSchema))
